@@ -7,7 +7,7 @@ from ..constants import log
 from ..constants import tol_path as tol
 from ..iteration import reduce_cascade
 from ..transformations import transform_points
-from ..typed import Iterable, NDArray, Number, Optional, Union, float64, int64
+from ..typed import ArrayLike, Iterable, NDArray, Number, Optional, Union, float64, int64
 from .simplify import fit_circle_check
 from .traversal import resample_path
 
@@ -173,7 +173,7 @@ def edges_to_polygons(edges: NDArray[int64], vertices: NDArray[float64]):
     ]
 
 
-def polygons_obb(polygons: Iterable[Polygon]):
+def polygons_obb(polygons: Union[Iterable[Polygon], ArrayLike]):
     """
     Find the OBBs for a list of shapely.geometry.Polygons
     """
